/*
# $BEGIN_SYNCGENIE_LICENSE$
# 
# This file is part of the SyncGenie project, a library for the Arduino IDE
# for interfacing with the the Teensy microcontroller via a SyncGenie
# breakout board (see https://osf.io/r9pb6/ ), with an emphasis on time
# synchronization in neuroscience experiments.
# 
# Author: Jeremy Hill (2024-)
# Development was supported by the NIH, NYS SCIRB, Veterans Affairs RRD,
# and the Stratton VA Medical Center.
# 
# No Copyright
# ============
# The author has dedicated this work to the public domain under the terms of
# Creative Commons' CC0 1.0 Universal legal code, waiving all of his rights to
# the work worldwide under copyright law, including all related and neighboring
# rights, to the extent allowed by law.
# 
# You can copy, modify, distribute and perform the work, even for commercial
# purposes, all without asking permission. See Other Information below.
# 
# Other Information
# =================
# In no way are the patent or trademark rights of any person affected by CC0,
# nor are the rights that other persons may have in the work or in how the work
# is used, such as publicity or privacy rights.
# 
# The author makes no warranties about the work, and disclaims liability for
# all uses of the work, to the fullest extent permitted by applicable law. When
# using or citing the work, you are requested to preserve the author attribution
# and this copyright waiver, but you should not imply endorsement by the author.
# 
# $END_SYNCGENIE_LICENSE$
*/

#ifndef   __Introspection_H__
#define   __Introspection_H__

// This file defines a static string called INTROSPECTION, which is suitable for use
// as an argument to SyncGenie::loadMessage() for displaying a scrollable message
// containing system information.  If you want, make a copy of this header in your
// sketch directory and replace the content---perhaps auto-replace the token `// @MORE@`
// with your own extensions of the meta-information, such as sketch name and version.

#include "SyncGenie.h"

const char INTROSPECTION[] =
	// @START@
	"SyncGenie v." QUOTE( SYNCGENIE_BOARD_REVISION ) "\n"
	"Teensy version: " TEENSY_VERSION 
#	if TEENSY_LONGBOARD
		" (long)\n"
#	else
		" (short)\n"
#	endif
	// @MORE@
;


#endif // __Introspection_H__
