/*
# $BEGIN_SYNCGENIE_LICENSE$
# 
# This file is part of the SyncGenie project, a library for the Arduino IDE
# for interfacing with the the Teensy microcontroller via a SyncGenie
# breakout board (see https://osf.io/r9pb6/ ), with an emphasis on time
# synchronization in neuroscience experiments.
# 
# Author: Jeremy Hill (2024-)
# Development was supported by the NIH, NYS SCIRB, Veterans Affairs RRD,
# and the Stratton VA Medical Center.
# 
# No Copyright
# ============
# The author has dedicated this work to the public domain under the terms of
# Creative Commons' CC0 1.0 Universal legal code, waiving all of his rights to
# the work worldwide under copyright law, including all related and neighboring
# rights, to the extent allowed by law.
# 
# You can copy, modify, distribute and perform the work, even for commercial
# purposes, all without asking permission. See Other Information below.
# 
# Other Information
# =================
# In no way are the patent or trademark rights of any person affected by CC0,
# nor are the rights that other persons may have in the work or in how the work
# is used, such as publicity or privacy rights.
# 
# The author makes no warranties about the work, and disclaims liability for
# all uses of the work, to the fullest extent permitted by applicable law. When
# using or citing the work, you are requested to preserve the author attribution
# and this copyright waiver, but you should not imply endorsement by the author.
# 
# $END_SYNCGENIE_LICENSE$
*/

#ifndef   __SyncGeniePins_H__
#define   __SyncGeniePins_H__

#include "SyncGenieTeensyVersioning.h"

static const int BOARD_REVISION = 0;
// dummy revision, should be compatible with any board architecture since no pins are used except LED_BUILTIN

static const int D0_OUT    = -1;
static const int D1_OUT    = -1;
static const int D2_OUT    = -1;
static const int D3_OUT    = -1;
static const int D4_OUT    = -1;
static const int D5_OUT    = -1;
static const int D6_OUT    = -1;
static const int D7_OUT    = -1;

static const int D8_LED    = -1;
static const int D9_LED    = LED_BUILTIN;

static const int D7_IN     = -1;
static const int D6_IN     = -1;
static const int D5_IN     = -1;
static const int D4_IN     = -1;
static const int D3_IN     = -1;
static const int D2_IN     = -1;
static const int D1_IN     = -1;
static const int D0_IN     = -1;

static const int RJ45_PIN1 = -1;
static const int RJ45_PIN2 = -1;

static const int SELECTOR_BUTTON = -1;
static const int SELECTOR_A      = -1;
static const int SELECTOR_B      = -1;
static const int BUTTON          = -1;
static const int BNC1            = -1;
static const int BNC2            = -1;
static const int POT1            = -1;
static const int POT2            = -1;
static const int JST_PIN3        = -1;
static const int JST_PIN4        = -1;
static const int TRS1_TIP        = -1;
static const int TRS1_RING       = -1;
static const int TRS2_TIP        = -1;
static const int TRS2_RING       = -1;
static const int TRS3_TIP        = -1;
static const int TRS3_RING       = -1;
static const int TRS4_TIP        = -1;
static const int TRS4_RING       = -1;
static const int LCD_RS          = -1;
static const int LCD_EN          = -1;
static const int LCD_D4          = -1;
static const int LCD_D5          = -1;
static const int LCD_D6          = -1;
static const int LCD_D7          = -1;

#ifdef __FakeLiquidCrystal_H__
	static const int LCD_COLS        = 16;
	static const int LCD_ROWS        =  2;
#else
	static const int LCD_COLS        = -1;
	static const int LCD_ROWS        = -1;
#endif

#endif // __SyncGeniePins_H__
